package App::dirstrata ;  
our $VERSION = '0.030' ; 
our $DATE = '2023-03-241T13:20+09:00' ; 

=encoding utf8

=head1 NAME

App::dirstrata -- 「何階層潜った所から最大何階層下までディレクトリを持つディレクトリが何個存在するか」を三角行列状に示す。

 dirstrata -- 他に dirdig dirdim dirdist というコマンドも作るので、それに名前を合わせた。2次元行列状の出力なので2回同じ語を繰り返した。

=head1 SYNOPSIS

This module provides a Unix-like command `F<dirstrata>'.

=head1 DESCRIPTION


=head1 AUTHOR

下野寿之 Toshiyuki SHIMONO <bin4tsv@gmail.com> 統計数理研究所 外来研究員

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2023 Toshiyuki SHIMONO. All rights reserved.
This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut

1 ;
